==> avodel-web-bot-4.0.0-10934b.zip: src/DependencyInjection/AvodelWebBotExtension.php <==
<?php

namespace Avodel\WebBot\DependencyInjection;

use Avodel\WebBot\Extension\Ajax\WaitUntilAjaxRequestsFinishedAction;
use Avodel\WebBot\Extension\Captcha\CaptchaCheckboxFrameDisappearedExceptionHandler;
use Avodel\WebBot\Extension\Captcha\CaptchaVerifierAction;
use Avodel\WebBot\Extension\Network\BadGatewayAction;
use Avodel\WebBot\Extension\Network\ClientClosedRequestAction;
use Avodel\WebBot\Extension\Network\NetworkErrorAction;
use Avodel\WebBot\Extension\Pause\PauseBetweenUserActionsAction;
use Avodel\WebBot\Extension\TimeLimit\StopWorkerOnTimeLimitAction;
use Avodel\WebBot\Extension\WebDriver\FallbackAction;
use Avodel\WebBot\Extension\WebDriver\FallbackExceptionHandler;
use Avodel\WebBot\Extension\WebDriver\StartWebDriverAction;
use Symfony\Component\Config\FileLocator;
use Symfony\Component\DependencyInjection\ContainerBuilder;
use Symfony\Component\DependencyInjection\Extension\Extension;
use Symfony\Component\DependencyInjection\Loader\YamlFileLoader;

final class AvodelWebBotExtension extends Extension
{
    public function load(array $configs, ContainerBuilder $container): void
    {
        $configuration = new Configuration();
        $config = $this->processConfiguration($configuration, $configs);

        $loader = new YamlFileLoader($container, new FileLocator(__DIR__ . '/../Resources/config'));
        $loader->load('services.yaml');

        foreach ($config['profile'] as $profile => $profileConfig) {
            $actions = [
                // default system actions
                StopWorkerOnTimeLimitAction::class,
                StartWebDriverAction::class,
                PauseBetweenUserActionsAction::class,
                CaptchaVerifierAction::class,
                WaitUntilAjaxRequestsFinishedAction::class,
            ];

            array_push($actions, ...$profileConfig['actions']);

            array_push(
                $actions,
                BadGatewayAction::class,
                ClientClosedRequestAction::class,
                NetworkErrorAction::class,
                FallbackAction::class,
            );

            $container->setParameter('avodel.web_bot.profile.' . $profile . '.actions', $actions);

            $exceptionHandlers = $profileConfig['exception_handlers'];
            array_unshift($exceptionHandlers, CaptchaCheckboxFrameDisappearedExceptionHandler::class);

            $exceptionHandlers[] = FallbackExceptionHandler::class;

            $container->setParameter('avodel.web_bot.profile.' . $profile . '.exception_handlers', $exceptionHandlers);
        }

        $container->setParameter('avodel.web_bot.profiles', array_keys($config['profile']));
    }
}

==> avodel-web-bot-4.4.1-b09791.zip: src/DependencyInjection/AvodelWebBotExtension.php <==
<?php

namespace Avodel\WebBot\DependencyInjection;

use Avodel\WebBot\Extension\Ajax\WaitUntilAjaxRequestsFinishedAction;
use Avodel\WebBot\Extension\Captcha\CaptchaCheckboxFrameDisappearedExceptionHandler;
use Avodel\WebBot\Extension\Captcha\CaptchaVerifierAction;
use Avodel\WebBot\Extension\Captcha\WaitForCaptchaWidgetReadinessAction;
use Avodel\WebBot\Extension\Frame\FrameNotFoundOrNotSwitchableExceptionHandler;
use Avodel\WebBot\Extension\Network\BadGatewayAction;
use Avodel\WebBot\Extension\Network\ClientClosedRequestAction;
use Avodel\WebBot\Extension\Network\NetworkErrorAction;
use Avodel\WebBot\Extension\Pause\PauseBetweenUserActionsAction;
use Avodel\WebBot\Extension\TimeLimit\StopWorkerOnTimeLimitAction;
use Avodel\WebBot\Extension\WebDriver\FallbackAction;
use Avodel\WebBot\Extension\WebDriver\FallbackExceptionHandler;
use Avodel\WebBot\Extension\WebDriver\StartWebDriverAction;
use Symfony\Component\Config\FileLocator;
use Symfony\Component\DependencyInjection\ContainerBuilder;
use Symfony\Component\DependencyInjection\Extension\Extension;
use Symfony\Component\DependencyInjection\Loader\YamlFileLoader;

final class AvodelWebBotExtension extends Extension
{
    public function load(array $configs, ContainerBuilder $container): void
    {
        $configuration = new Configuration();
        $config = $this->processConfiguration($configuration, $configs);

        $loader = new YamlFileLoader($container, new FileLocator(__DIR__ . '/../Resources/config'));
        $loader->load('services.yaml');

        foreach ($config['profile'] as $profile => $profileConfig) {
            $actions = [
                // default system actions
                StopWorkerOnTimeLimitAction::class,
                StartWebDriverAction::class,
                PauseBetweenUserActionsAction::class,
                WaitForCaptchaWidgetReadinessAction::class,
                CaptchaVerifierAction::class,
                WaitUntilAjaxRequestsFinishedAction::class,
            ];

            array_push($actions, ...$profileConfig['actions']);

            array_push(
                $actions,
                BadGatewayAction::class,
                ClientClosedRequestAction::class,
                NetworkErrorAction::class,
                FallbackAction::class,
            );

            $container->setParameter('avodel.web_bot.profile.' . $profile . '.actions', $actions);

            $exceptionHandlers = $profileConfig['exception_handlers'];
            array_unshift($exceptionHandlers,
                CaptchaCheckboxFrameDisappearedExceptionHandler::class,
                FrameNotFoundOrNotSwitchableExceptionHandler::class,
            );

            $exceptionHandlers[] = FallbackExceptionHandler::class;

            $container->setParameter('avodel.web_bot.profile.' . $profile . '.exception_handlers', $exceptionHandlers);
        }

        $container->setParameter('avodel.web_bot.profiles', array_keys($config['profile']));
        $container->setParameter('avodel.web_bot.backoff_delay_ms', $config['backoff_delay_ms']);
    }
}
